Name change
[c11tester.git] / main.cc
diff --git a/main.cc b/main.cc
index bcdafc482a5ff7de6111f64a4d0c824d9759af64..12fc3e17c717cdc04c300bb19d111bb8a3627f7e 100644 (file)
--- a/main.cc
+++ b/main.cc
@@ -171,13 +171,13 @@ int main(int argc, char **argv)
        main_argv = argv;
 
        /*
* If this printf statement is removed, C11Fuzzer will fail on an
         * assert on some versions of glibc.  The first time printf is
         * called, it allocated internal buffers.  We can't easily snapshot
         * libc since we also use it.
         */
 
-       printf("C11Fuzzer\n"
+       printf("C11Tester\n"
                                 "Copyright (c) 2013 and 2019 Regents of the University of California. All rights reserved.\n"
                                 "Distributed under the GPLv2\n"
                                 "Written by Weiyu Luo, Brian Norris, and Brian Demsky\n\n");
@@ -171,13 +171,13 @@ int main(int argc, char **argv)
 
        /*
-        * If this printf statement is removed, C11Fuzzer will fail on an
+        * If this printf statement is removed, C11Tester will fail on an
         * assert on some versions of glibc.  The first time printf is
         * called, it allocated internal buffers.  We can't easily snapshot